#main geo downloader drive code
from typing import Optional
from pathlib import Path

def download(gse_id, annot_column ,annot_type, gpl_id: Optional[str] = " "):
	'''This function takes in two parameters 1: gse_id - required, 2: gpl_id - not required
	and returns 4 objects:
	1: filename: str - name of GCT file
	2: df_exp_mat: DataFrame - expression matrix for the dataset
	3: df_meta: DataFrame - sample level meta data
	4: df_study_meta: DataFrame - study level meta data'''
	import pandas as pd
	import rpy2.robjects as robjects
	from rpy2.robjects import pandas2ri
	# Defining the R script and loading the instance in Python
	r = robjects.r
	path=str(Path(__file__).parent)
	r.assign('path',path)
	r['source'](path+"/geo_download_helper.R") #or define path to geo_downloader.R
	
	# Loading the function we have defined in R.
	download_function_r = robjects.globalenv['download']
	df_result_r = download_function_r(input_gse = gse_id,annot_column = annot_column ,annot_type = annot_type, input_gpl = gpl_id)
	
	#Converting it back to a pandas dataframe.
	df_meta = pd.DataFrame(pandas2ri.rpy2py(df_result_r[2])) #sample meta data 
	print(df_meta.head())
	df_exp_mat = pandas2ri.rpy2py(df_result_r[1]) #expression matrix
	df_study_meta = pandas2ri.rpy2py(df_result_r[3]) #study meta data
	filename = robjects.FactorVector(df_result_r[0]) #filename of gct created/can be skipped and gct can be created again
	filename = list(filename.levels)[0] 
	log2_transform_run = str(df_result_r.rx2['log2_transform_run'])
	print(log2_transform_run)
	return filename,df_exp_mat,df_meta,df_study_meta,log2_transform_run

def push():
	'''TODO'''
	pass

if __name__ == "__main__":
    pass